#!/bin/bash

# Read GPU list conf file

device_list=(
  "/dev/dri/card0"
  "/dev/mwv206_0"
  # Add more device paths to the list if needed
)

device=""
for dev in "${device_list[@]}"; do
  if [[ -e "$dev" ]]; then
    device="$dev"
    break
  fi
done

if [[ -z "$device" ]]; then
  echo "No device found in the device list."
  exit 1
fi

echo "Device: $device"

driver_name=""
if [[ "$device" == "/dev/dri/card0" ]]; then
  driver=$(readlink /sys/class/drm/$(basename "$device")/device/driver/module)
  driver_name=$(basename "$driver")
elif [[ "$device" == "/dev/mwv206_"* ]]; then
  driver_name="mwv206"
fi

echo "Driver Name: $driver_name"

rm -f /etc/ld.so.conf.d/10_gpudrv_path.conf
rm -f /usr/share/X11/xorg.conf.d/10-mwv206.conf

gl_dir="/usr/lib/loongarch64-linux-gnu/libglvnd"
# Check if driver name matches any of the names in the driver list
conf_file="/usr/share/gpudriverpath/${driver_name}_path.conf"
if [[ -f "${conf_file}" ]]; then
    echo "Matching conf file found: ${conf_file}"

    # Read the path and GLMD5 fields from the config file
    driver_dir=$(awk -F':' '/path:/ {print $2}' "${conf_file}")
    glmd5=$(awk -F':' '/GLMD5:/ {print $2}' "${conf_file}")

    if [[ -n "${driver_dir}" ]]; then
        echo "Adding ${driver_dir} to ldconfig search path"

        # Check the MD5 checksum of libGL.so in the driver_dir
        libgl_path="${driver_dir}/libGL.so"
        if [[ -f "${libgl_path}" ]]; then
            current_glmd5=$(md5sum "${libgl_path}" | awk '{print $1}')
            if [[ "${current_glmd5}" = "${glmd5}" ]]; then
                echo "MD5 checksum matched. Config directory is valid."
		gl_dir=${driver_dir}
            else
                echo "MD5 checksum mismatch. Config directory is not valid."
            fi
        else
            echo "libGL.so not found in ${driver_dir}. Config directory is not valid."
        fi
    else
        echo "No path field found in ${conf_file}"
    fi
else
    echo "Driver ${driver_name} not in the driver list"
fi
echo "${gl_dir}" > "/etc/ld.so.conf.d/10_gpudrv_path.conf"
ln -sf "${gl_dir}/libGL.so" /usr/lib/loongarch64-linux-gnu/libGL.so
libegl_path="${gl_dir}/libEGL.so"
if [[ -f "${libegl_path}" ]]; then
	ln -sf "${libegl_path}" /usr/lib/loongarch64-linux-gnu/libEGL.so
fi
libglesv2_path="${gl_dir}/libGLESv2.so"
if [[ -f "${libglesv2_path}" ]]; then
	ln -sf "${libglesv2_path}" /usr/lib/loongarch64-linux-gnu/libGLESv2.so
fi
if [[ "$driver_name" = "mwv206" ]]; then
  cp "/usr/share/X11/xorg.conf.d/10-mwv206.conf.jm7200" "/usr/share/X11/xorg.conf.d/10-mwv206.conf"
fi
ldconfig
